/*
 * adc_watchdog.c
 *
 *  Created on: Jan 15, 2023
 *      Author: hussamaldean
 */
#include "adc_watchdog.h"
#include "stm32f4xx.h"



void adc_watchDog_Init(uint16_t low_threshold, uint16_t high_threshold)
{
	/*Enable clock access to GPIOA*/
	RCC->AHB1ENR|=RCC_AHB1ENR_GPIOAEN;
	/*Set PA0 as analog mode*/
	GPIOA->MODER|=GPIO_MODER_MODE0;
	/*Enable clock access to ADC1*/
	RCC->APB2ENR|=RCC_APB2ENR_ADC1EN;

	/*Enable continuous conversion*/
	ADC1->CR2|=ADC_CR2_CONT;

	/*Enable watch dog on single channel*/
	ADC1->CR1|=ADC_CR1_AWDSGL;

	/*Enable watch dog interrupt*/

	ADC1->CR1|=ADC_CR1_AWDIE;

	/*Enable ADC1 interrupt in NVIC*/
	NVIC_EnableIRQ(ADC_IRQn);

	/*Set the low threshold*/

	ADC1->LTR=0;
	ADC1->LTR=low_threshold;

	/*Set the high threshold*/

	ADC1->HTR=0;
	ADC1->HTR=high_threshold;

	/*Set watch dog channel channel to be channel 0*/

	ADC1->CR1&=~(0x1F<<ADC_CR1_AWDCH_Pos);

	/*Enable analog watchdog on regular channel*/

	ADC1->CR1|=ADC_CR1_AWDEN;

	/*Enable the ADC module*/

	ADC1->CR2|=ADC_CR2_ADON;

	/*Start the conversion*/

	ADC1->CR2|=ADC_CR2_SWSTART;

}
